"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


# import degget
# import games_help
# import packages
from degget import show
from games_help import gen_ru_words
from packages import install, pip_upgrade, required

__author__ = 'Superior_6564'
__version__ = '0.0.3'
__email__ = 'vip.klochayil@gmail.com'
